summaryrefslogtreecommitdiff
path: root/src/dropbox.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/dropbox.c')
-rw-r--r--src/dropbox.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/dropbox.c b/src/dropbox.c
index 0d59559..e5782e3 100644
--- a/src/dropbox.c
+++ b/src/dropbox.c
@@ -2,22 +2,22 @@
* Copyright 2008 Evenflow, Inc.
*
* dropbox.c
* Nautilus module registering functions for the Dropbox extension.
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -30,30 +30,30 @@
#include <gdk/gdk.h>
#include <gtk/gtk.h>
-#include "nautilus-dropbox.h"
+#include "caja-dropbox.h"
static GType type_list[1];
void
-nautilus_module_initialize (GTypeModule *module) {
+caja_module_initialize (GTypeModule *module) {
g_print ("Initializing %s\n", PACKAGE_STRING);
- nautilus_dropbox_register_type (module);
- type_list[0] = NAUTILUS_TYPE_DROPBOX;
+ caja_dropbox_register_type (module);
+ type_list[0] = CAJA_TYPE_DROPBOX;
- dropbox_use_nautilus_submenu_workaround
- = (NAUTILUS_VERSION_MAJOR < 2 ||
- (NAUTILUS_VERSION_MAJOR == 2 && NAUTILUS_VERSION_MINOR <= 22));
+ dropbox_use_caja_submenu_workaround
+ = (CAJA_VERSION_MAJOR < 2 ||
+ (CAJA_VERSION_MAJOR == 2 && CAJA_VERSION_MINOR <= 22));
dropbox_use_operation_in_progress_workaround = TRUE;
}
void
-nautilus_module_shutdown (void) {
+caja_module_shutdown (void) {
g_print ("Shutting down dropbox extension\n");
}
void
-nautilus_module_list_types (const GType **types,
+caja_module_list_types (const GType **types,
int *num_types) {
*types = type_list;
*num_types = G_N_ELEMENTS (type_list);
@@ -2,22 +2,22 @@
*
* dropbox.c
- * Nautilus module registering functions for the Dropbox extension.
+ * Caja module registering functions for the Dropbox extension.
*
@@ -2,22 +2,22 @@
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -2,22 +2,22 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -2,22 +2,22 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the